@@ -5,19 +5,19 @@ import logging
 
 from ._core import EAN13, to_isbn13
 from ._exceptions import NotRecognizedServiceError, NotValidISBNError
-from ._openled import query as _oed
 from ._thinged import query as _ted
 from ._wikied import query as _wiki
 from .dev import cache, vias
 
-PROVIDERS = ('any', 'merge', 'openl', 'thingl', 'wiki')
+PROVIDERS = ('any', 'merge', 'wiki', 'thingl')
 LOGGER = logging.getLogger(__name__)
 
 
 # pylint: disable=broad-except
+# pylint: disable=consider-using-dict-items
 def _fake_provider_any(isbn):
     """Fake provider 'any' service."""
-    providers = {'wiki': _wiki, 'openl': _oed, 'thingl': _ted}
+    providers = {'wiki': _wiki, 'thingl': _ted}
     for provider in providers:
         try:
             data = providers[provider](isbn)
@@ -37,12 +37,11 @@ def _fake_provider_any(isbn):
 def _fake_provider_merge(isbn):
     """Fake provider 'merge' service."""
     try:  # pragma: no cover
-        named_tasks = (('openl', _oed), ('thingl', _ted), ('wiki', _wiki))
+        named_tasks = (('thingl', _ted), ('wiki', _wiki))
         results = vias.parallel(named_tasks, isbn)
-        odata = results.get('openl', set())
         tdata = results.get('thingl', set())
         wdata = results.get('wiki', set())
-        return list(odata | tdata | wdata)
+        return list(tdata | wdata)
     except Exception:  # pragma: no cover
         LOGGER.error("Some error on editions 'merge' service for %s!", isbn)
         return [isbn]
@@ -55,8 +54,6 @@ def get_editions(isbn, service):
         eds = _fake_provider_merge(isbn)
     if service == 'any':
         eds = _fake_provider_any(isbn)
-    if service == 'openl':
-        eds = list(_oed(isbn))
     if service == 'thingl':
         eds = list(_ted(isbn))
     if service == 'wiki':
